<div class="main-content-inner">
    {% block  breadcrumbs %}
        <div class="breadcrumbs ace-save-state" id="breadcrumbs">
            {% block breadcrumb %}
            {% endblock %}
            {% block search %}
                {% ifequal  view_type 'list' %}
                    {% include "base/search.html" %}
                {% endifequal %}
            {% endblock %}
        </div>
    {% endblock %}
    {% block ace-settings-container %}{% endblock ace-settings-container %}
    {% block  pre-page-content %}{% endblock %}
    {% block  page-content %}
        <div class="page-content">
            <div class="row">
                <div class="col-xs-12">
                    {% include "base/messages.html" %}
                    {% block content %}
                    {% endblock %}
                </div>
            </div>
        </div>
    {% endblock %}
    {% block  post-page-content %}{% endblock %}
</div>
{% block script %}
{% endblock %}