<div id="navbar" class="navbar navbar-default ace-save-state">
    <div class="navbar-container ace-save-state" id="navbar-container">
        <button type="button" class="navbar-toggle menu-toggler pull-left" id="menu-toggler" data-target="#sidebar">
            <span class="sr-only">Toggle sidebar</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
        </button>
        {% block form-navbar-header %}
            <div class="navbar-header pull-left">
                <a class="navbar-brand">
                    <small>
                        <i class="fa fa-leaf"></i>{{ site_name }} {{ role_name }}
                    </small>
                </a>
            </div>
        {% endblock %}
        <div class="navbar-buttons navbar-header pull-right" role="navigation">
            <ul class="nav ace-nav">
                <li class="light-blue dropdown-modal">
                    <a data-toggle="dropdown" class="dropdown-toggle">
                        <span class="user-info"> <small>已登录</small> {{ user.title }} </span>
                        <i class="ace-icon fa fa-caret-down"></i>
                    </a>
                    <ul class="user-menu dropdown-menu-right dropdown-menu dropdown-yellow dropdown-caret dropdown-close">
                        <li class="divider"></li>
                        <li><a href="{{url_prefix}}/user/login"> <i class="ace-icon fa fa-power-off"></i> 退出 </a></li>
                    </ul>
                </li>
            </ul>
        </div>
    </div><!-- /.navbar-container -->
</div>