{% load resource %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"/>
    <meta charset="utf-8"/>
    <title>{{ site_name }}</title>
    <meta name="description" content=""/>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0"/>
    <!-- bootstrap & fontawesome -->

    <link rel="icon" href="{% resource 'favicon.ico' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/bootstrap.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/font-awesome/4.5.0/css/font-awesome.min.css' %}"/>
    <!-- page specific plugin styles -->
    <link rel="stylesheet" href="{% resource 'ace/css/jquery-ui.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/jquery-ui.custom.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/chosen.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/bootstrap-datepicker3.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/bootstrap-timepicker.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/daterangepicker.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/bootstrap-datetimepicker.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/bootstrap-colorpicker.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/ui.jqgrid.min.css' %}"/>
    <!-- text fonts -->
    <link rel="stylesheet" href="{% resource 'ace/css/fonts.googleapis.com.css' %}"/>
    <!-- ace styles -->
    <link rel="stylesheet" href="{% resource 'ace/css/ace.min.css' %}" class="ace-main-stylesheet" id="main-ace-style"/>
    <!--[if lte IE 9]>
	<link rel="stylesheet" href="{% resource 'ace/css/ace-part2.min.css' %}" class="ace-main-stylesheet" />
	<![endif]-->
    <link rel="stylesheet" href="{% resource 'ace/css/ace-skins.min.css' %}"/>
    <link rel="stylesheet" href="{% resource 'ace/css/ace-rtl.min.css' %}"/>
    <!--[if lte IE 9]>
	<link rel="stylesheet" href="{% resource 'ace/css/ace-ie.min.css' %}" />
	<![endif]-->

    <!-- inline styles related to this page -->
    <!-- ace settings handler -->
    <script src="{% resource 'ace/js/jquery-2.1.4.min.js' %}"></script>
    <script src="{% resource 'ace/js/ace-extra.min.js' %}"></script>
    <!-- HTML5shiv and Respond.js for IE8 to support HTML5 elements and media queries -->
    <!--[if lte IE 8]>
	<script src="{% resource 'ace/js/html5shiv.min.js' %}"></script>
	<script src="{% resource 'ace/js/respond.min.js' %}"></script>
	<![endif]-->

</head>
<body class="no-skin" id="body">
<div style="display:none">page-index-page</div>
{% include "index/navbar.html" %}
{% include "index/elements.html" %}

<div class="main-container ace-save-state" id="main-container">
    <script type="text/javascript">
        try {
            ace.settings.loadState('main-container')
        } catch (e) {
        }
    </script>
    {% include "index/sidebar.html" %}
    <div class="main-content" id="main-content"></div>
    {% include "index/footer.html" %}
    <a id="btn-scroll-up" class="btn-scroll-up btn btn-sm btn-inverse">
        <i class="ace-icon fa fa-angle-double-up icon-only bigger-110"></i>
    </a>
</div><!-- /.main-container -->

{% block prescript %}{% endblock %}
<!-- basic scripts -->
<!--[if !IE]> -->
<!-- <![endif]-->
<!--[if IE]>
        <script src="{% resource 'ace/js/jquery-1.11.3.min.js' %}"></script>
        <![endif]-->
<script type="text/javascript">
    if ('ontouchstart' in document.documentElement) {
        document.write("<script src='{% resource 'ace/js/jquery.mobile.custom.min.js' %}'>" + "<" + "/script>");
    }
</script>

<script src="{% resource 'ace/js/moment.min.js' %}"></script>
<script src="{% resource 'ace/js/bootstrap.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery-ui.custom.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery.ui.touch-punch.min.js' %}"></script>
<script src="{% resource 'ace/js/chosen.jquery.min.js' %}"></script>
<script src="{% resource 'ace/js/spinbox.min.js' %}"></script>
<script src="{% resource 'ace/js/bootstrap-datepicker.min.js' %}"></script>
<script src="{% resource 'ace/js/bootstrap-timepicker.min.js' %}"></script>
<script src="{% resource 'ace/js/moment.min.js' %}"></script>
<script src="{% resource 'ace/js/daterangepicker.min.js' %}"></script>
<script src="{% resource 'ace/js/bootstrap-datetimepicker.min.js' %}"></script>
<script src="{% resource 'ace/js/bootstrap-colorpicker.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery.knob.min.js' %}"></script>
<script src="{% resource 'ace/js/autosize.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery.inputlimiter.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery.maskedinput.min.js' %}"></script>
<script src="{% resource 'ace/js/bootstrap-tag.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery-ui.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery.ui.touch-punch.min.js' %}"></script>
<script src="{% resource 'ace/js/jquery.jqGrid.min.js' %}"></script>
<script src="{% resource 'ace/js/grid.locale-cn.js' %}"></script>
<script src="{% resource 'ace/js/bootbox.js' %}"></script>
<script src="{% resource 'ace/js/ace-elements.min.js' %}"></script>
<script src="{% resource 'ace/js/ace.min.js' %}"></script>
<script src="{% resource 'acmin/js/base64.js' %}"></script>
<script src="{% resource 'acmin/js/ui.js' %}"></script>
<script src="{% resource 'acmin/js/main.js?bbb' %}"></script>
<!-- inline scripts related to this page -->
<script>
    window.app_name = "{{ app_name }}";
    checkHash();
</script>
{% block postscript %}{% endblock %}
</body>
</html>