{% load resource %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"/>
    <meta charset="utf-8"/>
    <title>{{ function_name }}管理系统</title>

    <meta name="description" content="User login page"/>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0"/>

    <!-- bootstrap & fontawesome -->
    <link rel="stylesheet" href="{% resource 'ace/css/bootstrap.min.css'%}"/>
    <link rel="stylesheet" href="{% resource 'ace/font-awesome/4.5.0/css/font-awesome.min.css'%}"/>

    <!-- text fonts -->
    <link rel="stylesheet" href="{% resource 'ace/css/fonts.googleapis.com.css'%}"/>

    <!-- ace styles -->
    <link rel="stylesheet" href="{% resource 'ace/css/ace.min.css'%}"/>

    <!--[if lte IE 9]>
        <link rel="stylesheet" href="{% resource 'ace/css/ace-part2.min.css'%}" />
        <![endif]-->
    <link rel="stylesheet" href="{% resource 'ace/css/ace-rtl.min.css'%}"/>

    <!--[if lte IE 9]>
        <link rel="stylesheet" href="{% resource 'ace/css/ace-ie.min.css'%}" />
        <![endif]-->

    <!-- HTML5shiv and Respond.js for IE8 to support HTML5 elements and media queries -->

    <!--[if lte IE 8]>
        <script src="{% resource 'ace/js/html5shiv.min.js'%}"></script>
        <script src="{% resource 'ace/js/respond.min.js'%}"></script>
        <![endif]-->

<body class="login-layout">
<div style="display:none">reload-page</div>
<div class="main-container">
    <div class="main-content">
        <div class="row">
            <div class="col-sm-10 col-sm-offset-1">
                <div class="login-container">
                    <div class="center">
                        <h1>
                            <i class="ace-icon fa fa-leaf green"></i>
                            <span class="red">{{ function_name }}</span>
                            <span class="white" id="id-text2">管理系统</span>
                        </h1>
                    </div>

                    <div class="space-6"></div>

                    <div class="position-relative">
                        <div id="login-box" class="login-box visible widget-box no-border"></div>
                        <div class="widget-body">
                            <div class="widget-main">
                                <h4 class="header blue lighter bigger">
                                    <i class="ace-icon fa fa-coffee green"></i>
                                    请登录系统
                                </h4>

                                {% if form.non_field_errors %}
                                    <div class="page-header">
                                        <div class="alert alert-danger" id="error">
                                            {% for message in form.non_field_errors %}
                                                <b>{{ message }}</b><br/>
                                            {% endfor %}
                                        </div>
                                    </div>
                                {% endif %}
                                <div class="space-6"></div>
                                <form method="post" action="?">
                                    {% csrf_token %}
                                    <fieldset>
                                        {% for field in form %}
                                            <label class="block clearfix">
                                                <span class="block input-icon input-icon-right">
                                                  {{ field }}{{ field.errors }}
                                                </span>
                                            </label>
                                        {% endfor %}
                                        <div class="space"></div>
                                        <div class="clearfix">
                                            <button type="submit" class="width-35 pull-right btn btn-sm btn-primary">
                                                <i class="ace-icon fa fa-key"></i>
                                                <span class="bigger-110">登录</span>
                                            </button>
                                        </div>
                                        <div class="space-4"></div>
                                    </fieldset>
                                    <input type="hidden" name="next" value=""/>
                                </form>
                            </div><!-- /.widget-main -->
                            <!-- /.widget-body -->
                        </div>
                        <!-- /.login-box -->
                    </div><!-- /.position-relative -->
                </div>
            </div><!-- /.col -->
        </div><!-- /.row -->
    </div><!-- /.main-content -->
</div><!-- /.main-container -->

<!-- basic scripts -->

<!--[if !IE]> -->
<script src="{% resource 'ace/js/jquery-2.1.4.min.js'%}"></script>

<!-- <![endif]-->

<!--[if IE]>
          <script src="{% resource 'ace/js/jquery-1.11.3.min.js'%}"></script>
          <![endif]-->
<script type="text/javascript">
    if ('ontouchstart' in document.documentElement)
        document.write("<script src='{% resource 'ace/js/jquery.mobile.custom.min.js'%}'>" + "<" + "/script>");
</script>
<!-- inline scripts related to this page -->
<script type="text/javascript">
    jQuery(function ($) {
        $('body').attr('class', 'login-layout blur-login');
        $('#id-text2').attr('class', 'white');
        $('#id-company-text').attr('class', 'light-blue');
    });
</script>
</body>
</html>

