<div id="sidebar" class="sidebar responsive ace-save-state">
    <script type="text/javascript">
        try {
            ace.settings.loadState('sidebar')
        } catch (e) {
        }
    </script>
    <ul class="nav nav-list">
        {% for k,l in nodes %}
            <li class='open'>
                <a href="javascript:;" class="dropdown-toggle">
                    <i class="menu-icon fa fa-list"></i>
                    <span class="menu-text"> {{ k }} </span>
                    <b class="arrow fa fa-angle-down"></b>
                </a>
                <b class="arrow"></b>
                <ul class="submenu">
                    {% for name,title in l %}
                        <li id="{{ name }}">
                            <a href="#!name=/{{ name }}/">
                                <i class="menu-icon fa fa-caret-right"></i> {{ title }}
                            </a>
                            <b class="arrow"></b>
                        </li>
                    {% endfor %}
                </ul>
            </li>
        {% endfor %}
    </ul><!-- /.nav-list -->
    <div class="sidebar-toggle sidebar-collapse" id="sidebar-collapse">
        <i id="sidebar-toggle-icon" class="ace-icon fa fa-angle-double-left ace-save-state"
           data-icon1="ace-icon fa fa-angle-double-left" data-icon2="ace-icon fa fa-angle-double-right"></i>
    </div>
</div>