from .base import get_base_view_class, get_view
from .create import AdminCreateView
from .delete import AdminDeleteView
from .export import AdminExportView
from .form import AdminFormView
from .list import AdminListView
from .mixins import StaticFilterMixin
from .update import AdminUpdateView
